==> v1.19.1.tar.gz: le-chat-php/lang_es_ES.php <==
<?php
/*
* LE CHAT-PHP - a PHP Chat based on LE CHAT - Spanish (ES) translation
*
* Copyright (C) 2015-2016 Daniel Winzen <d@winzen4.de>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

//Native language name: Español (España)
$T=array(
	'nodb' => '¡Sin conexión a la base de datos!',
	'nodbsetup' => '¡No pudo conectarse a la base de datos! Por favor crea la base de datos y edita el script para usarla con el nombre de usuario y clave dados.',
	'changelang' => 'Cambiar idioma:',
	'expire' => 'La sesión es inválida o expiró',
	'kicked' => '¡Te expulsaron!',
	'invalnick' => 'Apodo incorrecto (%d caracteres como máximo, no se permiten caracteres especiales)',
	'invalpass' => 'Contraseña inválida (como mínimo %d caracteres)',
	'noconfirm' => '¡La contraseña y su confirmación no coinciden!',
	'incorregex' => '¡Expresión regular incorrecta!',
	'bottom' => 'Inicio',
	'top' => 'Fin',
	'choose' => '(elija)',
	'setup' => 'Configuración del chat',
	'init' => 'Configuración inicial',
	'sulogin' => 'Registro de Superadministrador',
	'sunick' => 'Apodo del superadmin:',
	'supass' => 'Contraseña del superadmin:',
	'suconfirm' => 'Confirmar contraseña:',
	'susuccess' => '¡Registrado con éxito!',
	'initbtn' => 'Inicializar chat',
	'initdbexist' => '¡La base de datos ya existe! Para continuar, primero tienes que borrar esas tablas manualmente.',
	'initsuexist' => '¡Ya existe un superadministrador!',
	'initgosetup' => 'Ir a la página de configuración',
	'captcha' => 'Captcha',
	'enabled' => 'Habilitado',
	'onlyguests' => 'Sólo para invitados',
	'disabled' => 'Deshabilitado',
	'simple' => 'Simple',
	'moderate' => 'Moderado',
	'extreme' => 'Extremo',
	'nick' => 'Apodo:',
	'pass' => 'Constraseña:',
	'globalloginpass' => 'Contraseña global:',
	'login' => 'Identificarse',
	'dbupdate' => '¡La base de datos fue actualizada con éxito!',
	'sysmessages' => 'Mensajes de sistema',
	'msgenter' => 'Entrando',
	'msgexit' => 'Saliendo',
	'msgmemreg' => 'Miembro registrado',
	'msgsureg' => 'Aplicante registrado',
	'msgkick' => 'Expulsado',
	'msgmultikick' => 'Expulsión múltiple',
	'msgallkick' => 'Todos expulsados',
	'msgclean' => 'Sala limpiada',
	'dateformat' => '<a target="_blank" href="http://php.net/manual/en/function.date.php#refsect1-function.date-parameters">Date formating</a>',
	'admfunc' => 'Funciones administrativas',
	'allguests' => 'Todos invitados',
	'cleanmsgs' => 'Limpiar mensajes',
	'room' => 'Sala entera',
	'selection' => 'Selección',
	'cleannick' => 'Following nickname:',
	'clean' => 'Clean',
	'kickchat' => '<b>Expulsado</b> (%d minutos)',
	'kickreason' => 'Motivo de expulsión:',
	'kickpurge' => 'Mensaje de purga',
	'kick' => 'Expulsar',
	'logoutinact' => 'Desconectar persona inactiva',
	'logout' => 'Desconectar',
	'sessions' => 'Ver sesiones activas',
	'view' => 'Ver',
	'filter' => 'Filtro',
	'guestacc' => 'Change Guestaccess',
	'guestallow' => 'Permitir',
	'guestwait' => 'Permitir con sala de espera',
	'adminallow' => 'Requiere aprobación del moderator',
	'guestdisallow' => 'Sólo miembros',
	'addsuguest' => 'Agregar aplicante',
	'register' => 'Registrar',
	'admmembers' => 'Miembros',
	'memdel' => 'Borrar de la base de datos',
	'memdeny' => 'Denegar acceso (!)',
	'memsuguest' => 'Convertir en aplicante (G)',
	'memreg' => 'Convertir en miembro regular',
	'memmod' => 'Convertir en moderador (M)',
	'memsumod' => 'Convertir en supermoderador (SM)',
	'memadm' => 'Convertir administrador (A)',
	'change' => 'Cambiar',
	'regguest' => 'Registrar invitado',
	'regmem' => 'Registrar miembro nuevo',
	'sessact' => 'Sesiones activas',
	'sessnick' => 'Apodo',
	'sesstimeout' => 'Expiración',
	'sessua' => 'Navegador',
	'fid' => 'ID del filtro:',
	'match' => 'Coincidencia',
	'replace' => 'Reemplazar',
	'allowpm' => 'Permitir en MP',
	'regex' => 'Expresión regular',
	'apply' => 'Aplicar',
	'newfilter' => 'Filtro nuevo:',
	'add' => 'Añadir',
	'noframes' => 'Este chat usa <b>frames</b>. ¡Por favor, habilítalos en tu navegador o usa uno que los permita!',
	'delselmes' => 'Borrar mensajes seleccionados',
	'staffnotes' => 'Notas del equipo',
	'adminnotes' => 'Notas de administrador',
	'notessaved' => '¡Notas guardadas!',
	'lastedited' => 'Editada por última vez por %1$s el %2$s',
	'savenotes' => 'Guardar notas',
	'waitingroom' => 'Sala de espera',
	'waittext' => 'Bienvenido %1$s, tu identificación fue demorada, podrás acceder a la sala en %2$d segundos.',
	'admwaittext' => 'Bienvenido %1$s, tu identificación fue demorada, podrás acceder a la sala en cuanto un administrador lo permita.',
	'waitreload' => 'Si esta página no se actualiza cada %d segundos, usa el botón de abajo para hacerlo manualmente.',
	'reload' => 'Recargar',
	'rules' => 'Reglas',
	'talkto' => 'Enviar a',
	'toall' => 'Todos',
	'tomem' => 'Sólo miembros',
	'tostaff' => 'Sólo equipo',
	'toadmin' => 'Sólo administradores',
	'alsopurge' => 'Además purgar mensajes',
	'dellast' => 'Eliminar el último mensaje',
	'delall' => 'Eliminar todos los mensajes',
	'switchsingle' => 'Cambiar a una sola línea',
	'switchmulti' => 'Cambiar a múltiples líneas',
	'help' => 'Ayuda',
	'helpguest' => 'Todas las funciones deberían ser auto-explicativas, sólo usa los botones. En tu perfil puedes ajustar el tiempo de refresco, el color del texto y el tamaño de caja que prefieras.<br><u>Nota:</u> Esto es una sala de chat, así que si no te mantienes hablando, serás desconectado automáticamete luego de un tiempo.',
	'helpembed' => 'Si quieres incluir una imagen en tu publicación, simplemente pon [img] al comienzo de la dirección URL de la imagen. Por ejemplo: [img]http://example.com/images/file.jpg incluirá la imagen en tu publicación.',
	'helpmem' => 'Miembros: Tendrás algunas opciones adicionales en tu perfil. Podrás ajustar la tipografía del texto y cambiar la contraseña en cualquier momento.',
	'helpmod' => 'Moderadores: Nota el botón de administración al final de la página. Te llevará a una página donde puedes limpiar la sala, expulsar personas, ver todas las sesiones activas y deshabilitar el acceso a invitados totalmente si fuese necesario.',
	'helpadm' => 'Administradores: Además podrás registrar invitados, editar miembros y registrar nuevos apodos sin que estén en la sala.',
	'profile' => 'Tu perfil',
	'ignore' => 'Ignorar',
	'unignore' => 'Dejar de ignorar',
	'refreshrate' => 'Tiempo de actualización (5-150 segundos)',
	'fontcolour' => 'Color de texto',
	'viewexample' => 'Ver ejemplos',
	'bgcolour' => 'Color de fondo',
	'fontface' => 'Tipografía',
	'roomdefault' => 'Sala por defecto',
	'bold' => 'Negrita',
	'italic' => 'Bastardilla',
	'fontexample' => 'Ejemplo de la tipografía seleccionada',
	'timestamps' => 'Mostrar fecha y hora',
	'embed' => 'Habilitar imágenes (necesita cookies)',
	'incognito' => 'Modo incógnito',
	'pbsize' => 'Tamaño de la caja de publicación',
	'nbsize' => 'Tamaño de la caja de notas',
	'width' => 'Ancho:',
	'height' => 'Alto:',
	'changepass' => 'Cambiar la contraseña',
	'oldpass' => 'Contraseña anterior:',
	'newpass' => 'Contraseña nueva:',
	'confirmpass' => 'Confirmar contraseña nueva:',
	'savechanges' => 'Guardar cambios',
	'reloadpb' => 'Recargar caja de publicación',
	'reloadmsgs' => 'Recargar mensajes',
	'chgprofile' => 'Perfil',
	'adminbtn' => 'Admin',
	'admnotes' => 'Notas de administrador',
	'notes' => 'Notas',
	'clone' => 'Clone',
	'randh' => 'Reglas y ayuda',
	'exit' => 'Salir de la sala',
	'bye' => '¡Chau %s, visitanos pronto!',
	'colourtable' => 'Colourtable',
	'backtoprofile' => 'Volver a tu perfil',
	'copy' => 'Copiar:',
	'choosecol' => 'Invitado, elija un color:',
	'randomcol' => 'Color al azar',
	'enter' => 'Ingresar a la sala',
	'error' => 'Error',
	'members' => 'Miembros',
	'guests' => 'Invitados',
	'approveguests' => '%d nuevos invitados para aprobar',
	'allowchecked' => 'Aceptar marcados',
	'allowall' => 'Aceptar todos',
	'denychecked' => 'Rechazar marcados',
	'denyall' => 'Rechazar todos',
	'denymessage' => 'Enviar mensaje a rechazados:',
	'butallowdeny' => 'Enviar',
	'waitempty' => 'No hay más peticiones para aprobar.',
	'wrongcaptcha' => 'Captcha incorrecto',
	'captchaexpire' => 'Captcha ya usado o expirado.',
	'noguests' => '¡Perdón! Actualmente sólo se permiten miembros.',
	'curchat' => 'Actualmente hay %d personas en la sala:',
	'cantreg' => 'No pudo registrarse %s',
	'alreadyreged' => '%s ya fue registrado.',
	'successreg' => '%s se registro exitosamente.',
	'cantchgstat' => 'No pudo cambiarse el estado de %s',
	'succdel' => '%s fue eliminado de la base de datos.',
	'succchg' => 'Se cambió el estado de %s exitosamente.',
	'wrongpass' => '¡Constraseña incorrecta!',
	'wrongglobalpass' => '¡Constraseña global incorrecta!',
	'succprofile' => 'Tu perfil se guardó satisfactoriamente.',
	'backtologin' => 'Volver a la página de identificación.',
	'backtochat' => 'Vovler a la sala.',
	'Beige' => 'Beis',
	'Black' => 'Negro',
	'Blue' => 'Azul',
	'BlueViolet' => 'Azul violáceo',
	'Brown' => 'Marrón',
	'Cyan' => 'Cian',
	'DarkBlue' => 'Azul oscuro',
	'DarkGreen' => 'Verde oscuro',
	'DarkRed' => 'Rojo oscuro',
	'DarkViolet' => 'Violeta oscuro',
	'DeepSkyBlue' => 'Azul celeste',
	'Gold' => 'Dorado',
	'Grey' => 'Gris',
	'Green' => 'Verde',
	'HotPink' => 'Rosa cálido',
	'Indigo' => 'Índigo',
	'LightBlue' => 'Azul claro',
	'LightGreen' => 'Verde claro',
	'LimeGreen' => 'Verde lima',
	'Magenta' => 'Magenta',
	'Olive' => 'Oliva',
	'Orange' => 'Naranja',
	'OrangeRed' => 'Rojo anaranjado',
	'Purple' => 'Púrpura',
	'Red' => 'Rojo',
	'RoyalBlue' => 'Azul real',
	'SeaGreen' => 'Verde marino',
	'Sienna' => 'Siena',
	'Silver' => 'Plateado',
	'Tan' => 'Bronceado',
	'Teal' => 'Cerceta',
	'Violet' => 'Violeta',
	'White' => 'Blanco',
	'Yellow' => 'Amarillo',
	'YellowGreen' => 'Verde amarillento',
	'redirectto' => 'Redirigir hacia:',
	'nonhttp' => 'Petición de enlace que no es http:',
	'httpredir' => 'Si no funciona, prueba esto:',
	'actions' => 'Acciones',
	'sesip' => 'Dirección IP',
	'css' => 'Estilo CSS',
	'memberexpire' => 'Expiración para miembros (minutos)',
	'guestexpire' => 'Expiración para invitados (minutos)',
	'kickpenalty' => 'Penalidad al expulsar (minutos)',
	'entrywait' => 'Tiempo en sala de espera (segundos)',
	'captchatime' => 'Expiración de captcha (segundos)',
	'messageexpire' => 'Expiracíon de mensajes (minutos)',
	'messagelimit' => 'Límite de mensajes (público)',
	'maxmessage' => 'Largo máximo de mensaje',
	'confirm' => '¿Estás seguro?',
	'yes' => 'Sí',
	'no' => 'No',
	'colbg' => 'Color de fondo',
	'coltxt' => 'Color de texto',
	'maxname' => 'Largo máximo para apodos',
	'minpass' => 'Largo mínimo para contraseñas',
	'defaultrefresh' => 'Tiempo de refresco de mensajes por defecto (segundos)',
	'suguests' => 'Habilitar aplicantes',
	'rulestxt' => 'Reglas (html)',
	'imgembed' => 'Imágenes incrustadas',
	'trackip' => 'Mostrar IP de la sesión',
	'captchachars' => 'Caracteres usados en el Captcha',
	'memkick' => 'Los miembros pueden expulsar, si no hay moderador presente',
	'forceredirect' => 'Forzar redirección',
	'redirect' => 'Script de redirección personalizado',
	'backuprestore' => 'Respaldar y restaurar',
	'backup' => 'Respaldar',
	'restore' => 'Restaurar',
	'settings' => 'Preferencias',
	'linkfilter' => 'Filtro de enlaces',
	'enablejs' => 'Permitir  JavaScript para mejorar la carga de mensajes',
	'chatname' => 'Nombre de la sala',
	'destroy' => 'Destruir sala',
	'destroyed' => 'Sala destruida satisfactoriamente',
	'topic' => 'Asunto',
	'passreset' => 'Reiniciar contraseña',
	'cantresetpass' => 'Can\'t reset password',
	'succpassreset' => 'Successfully reset password',
	'entermsg' => '%s entró en la sala.',
	'exitmsg' => '%s se fue de la sala.',
	'memregmsg' => '%s ahora es un miembro registrado.',
	'suregmsg' => '%s ahora es un aplicante registrado.',
	'kickmsg' => '%s fue expulsado.',
	'multikickmsg' => '%s fueron expulsados.',
	'allkickmsg' => 'Todas las personas fueron expulsadas.',
	'cleanmsg' => '%s fue limpiada.',
	'sendallmsg' => '%s - ',
	'sendmemmsg' => '[M] %s - ',
	'sendmodmsg' => '[Equipo] %s - ',
	'sendadmmsg' => '[Admin] %s - ',
	'sendprvmsg' => '[%1$s a %2$s] - ',
	'msgsendall' => 'Mensajes a todos',
	'msgsendmem' => 'Sólo mensajes a miembros',
	'msgsendmod' => 'Sólo mensajes a equipo',
	'msgsendadm' => 'Sólo mensajes a administradores',
	'msgsendprv' => 'Mensaje privado',
	'numnotes' => 'Number of notes revisions to keep',
	'revisions' => 'Revisiones:',
	'older' => 'Older',
	'newer' => 'Newer',
	'accessdenied' => 'Acceso denegado',
	'loggedinas' => 'Estás identificado como %s y no tenés acceso a esta sección.',
	'newnickname' => 'Nuevo apodo:',
	'nicknametaken' => 'Ese apodo ya fue tomado',
	'nopass' => 'Constraseña incorrecta (al menos %d caracteres), no se cambia apodo'
);
?>

==> v1.22.1.tar.gz: le-chat-php/lang_es_ES.php <==
<?php
/*
* LE CHAT-PHP - a PHP Chat based on LE CHAT - Spanish (ES) translation
*
* Copyright (C) 2015-2016 Daniel Winzen <d@winzen4.de>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

//Native language name: Español (España)
$T=array(
	'nodb' => '¡Sin conexión a la base de datos!',
	'nodbsetup' => '¡No pudo conectarse a la base de datos! Por favor crea la base de datos y edita el script para usarla con el nombre de usuario y clave dados.',
	'changelang' => 'Cambiar idioma:',
	'expire' => 'La sesión es inválida o expiró',
	'kicked' => '¡Te expulsaron!',
	'noconfirm' => '¡La contraseña y su confirmación no coinciden!',
	'incorregex' => '¡Expresión regular incorrecta!',
	'bottom' => 'Inicio',
	'top' => 'Fin',
	'choose' => '(elija)',
	'setup' => 'Configuración del chat',
	'init' => 'Configuración inicial',
	'sulogin' => 'Registro de Superadministrador',
	'sunick' => 'Apodo del superadmin:',
	'supass' => 'Contraseña del superadmin:',
	'suconfirm' => 'Confirmar contraseña:',
	'susuccess' => '¡Registrado con éxito!',
	'initbtn' => 'Inicializar chat',
	'initdbexist' => '¡La base de datos ya existe! Para continuar, primero tienes que borrar esas tablas manualmente.',
	'initsuexist' => '¡Ya existe un superadministrador!',
	'initgosetup' => 'Ir a la página de configuración',
	'captcha' => 'Captcha',
	'enabled' => 'Habilitado',
	'onlyguests' => 'Sólo para invitados',
	'disabled' => 'Deshabilitado',
	'simple' => 'Simple',
	'moderate' => 'Moderado',
	'extreme' => 'Extremo',
	'nick' => 'Apodo:',
	'pass' => 'Constraseña:',
	'globalloginpass' => 'Contraseña global:',
	'login' => 'Identificarse',
	'dbupdate' => '¡La base de datos fue actualizada con éxito!',
	'sysmessages' => 'Mensajes de sistema',
	'msgenter' => 'Entrando',
	'msgexit' => 'Saliendo',
	'msgmemreg' => 'Miembro registrado',
	'msgsureg' => 'Aplicante registrado',
	'msgkick' => 'Expulsado',
	'msgmultikick' => 'Expulsión múltiple',
	'msgallkick' => 'Todos expulsados',
	'msgclean' => 'Sala limpiada',
	'dateformat' => '<a target="_blank" href="http://php.net/manual/en/function.date.php#refsect1-function.date-parameters">Date formating</a>',
	'admfunc' => 'Funciones administrativas',
	'allguests' => 'Todos invitados',
	'cleanmsgs' => 'Limpiar mensajes',
	'room' => 'Sala entera',
	'selection' => 'Selección',
	'cleannick' => 'Following nickname:',
	'clean' => 'Clean',
	'kickchat' => 'Expulsado (%d minutos)',
	'kickreason' => 'Motivo de expulsión:',
	'kickpurge' => 'Mensaje de purga',
	'kick' => 'Expulsar',
	'logoutinact' => 'Desconectar persona inactiva',
	'logout' => 'Desconectar',
	'sessions' => 'Ver sesiones activas',
	'view' => 'Ver',
	'filter' => 'Filtro',
	'guestacc' => 'Change Guestaccess',
	'guestallow' => 'Permitir',
	'guestwait' => 'Permitir con sala de espera',
	'adminallow' => 'Requiere aprobación del moderator',
	'guestdisallow' => 'Sólo miembros',
	'addsuguest' => 'Agregar aplicante',
	'register' => 'Registrar',
	'admmembers' => 'Miembros',
	'memdel' => 'Borrar de la base de datos',
	'memdeny' => 'Denegar acceso (!)',
	'memsuguest' => 'Convertir en aplicante (G)',
	'memreg' => 'Convertir en miembro regular',
	'memmod' => 'Convertir en moderador (M)',
	'memsumod' => 'Convertir en supermoderador (SM)',
	'memadm' => 'Convertir administrador (A)',
	'change' => 'Cambiar',
	'regguest' => 'Registrar invitado',
	'regmem' => 'Registrar miembro nuevo',
	'sessact' => 'Sesiones activas',
	'sessnick' => 'Apodo',
	'sesstimeout' => 'Expiración',
	'sessua' => 'Navegador',
	'fid' => 'ID del filtro:',
	'match' => 'Coincidencia',
	'replace' => 'Reemplazar',
	'allowpm' => 'Permitir en MP',
	'regex' => 'Expresión regular',
	'apply' => 'Aplicar',
	'newfilter' => 'Filtro nuevo:',
	'add' => 'Añadir',
	'noframes' => 'Este chat usa <b>frames</b>. ¡Por favor, habilítalos en tu navegador o usa uno que los permita!',
	'delselmes' => 'Borrar mensajes seleccionados',
	'staffnotes' => 'Notas del equipo',
	'adminnotes' => 'Notas de administrador',
	'notessaved' => '¡Notas guardadas!',
	'lastedited' => 'Editada por última vez por %1$s el %2$s',
	'savenotes' => 'Guardar notas',
	'waitingroom' => 'Sala de espera',
	'waittext' => 'Bienvenido %1$s, tu identificación fue demorada, podrás acceder a la sala en %2$d segundos.',
	'admwaittext' => 'Bienvenido %1$s, tu identificación fue demorada, podrás acceder a la sala en cuanto un administrador lo permita.',
	'waitreload' => 'Si esta página no se actualiza cada %d segundos, usa el botón de abajo para hacerlo manualmente.',
	'reload' => 'Recargar',
	'rules' => 'Reglas',
	'talkto' => 'Enviar a',
	'toall' => 'Todos',
	'tomem' => 'Sólo miembros',
	'tostaff' => 'Sólo equipo',
	'toadmin' => 'Sólo administradores',
	'alsopurge' => 'Además purgar mensajes',
	'dellast' => 'Eliminar el último mensaje',
	'delall' => 'Eliminar todos los mensajes',
	'switchsingle' => 'Cambiar a una sola línea',
	'switchmulti' => 'Cambiar a múltiples líneas',
	'help' => 'Ayuda',
	'helpguest' => 'Todas las funciones deberían ser auto-explicativas, sólo usa los botones. En tu perfil puedes ajustar el tiempo de refresco, el color del texto y el tamaño de caja que prefieras.<br><u>Nota:</u> Esto es una sala de chat, así que si no te mantienes hablando, serás desconectado automáticamete luego de un tiempo.',
	'helpembed' => 'Si quieres incluir una imagen en tu publicación, simplemente pon [img] al comienzo de la dirección URL de la imagen. Por ejemplo: [img]http://example.com/images/file.jpg incluirá la imagen en tu publicación.',
	'helpmem' => 'Miembros: Tendrás algunas opciones adicionales en tu perfil. Podrás ajustar la tipografía del texto y cambiar la contraseña en cualquier momento.',
	'helpmod' => 'Moderadores: Nota el botón de administración al final de la página. Te llevará a una página donde puedes limpiar la sala, expulsar personas, ver todas las sesiones activas y deshabilitar el acceso a invitados totalmente si fuese necesario.',
	'helpadm' => 'Administradores: Además podrás registrar invitados, editar miembros y registrar nuevos apodos sin que estén en la sala.',
	'profile' => 'Tu perfil',
	'ignore' => 'Ignorar',
	'unignore' => 'Dejar de ignorar',
	'refreshrate' => 'Tiempo de actualización (5-150 segundos)',
	'fontcolour' => 'Color de texto',
	'viewexample' => 'Ver ejemplos',
	'bgcolour' => 'Color de fondo',
	'fontface' => 'Tipografía',
	'roomdefault' => 'Sala por defecto',
	'bold' => 'Negrita',
	'italic' => 'Bastardilla',
	'fontexample' => 'Ejemplo de la tipografía seleccionada',
	'timestamps' => 'Mostrar fecha y hora',
	'embed' => 'Habilitar imágenes',
	'incognito' => 'Modo incógnito',
	'pbsize' => 'Tamaño de la caja de publicación',
	'nbsize' => 'Tamaño de la caja de notas',
	'width' => 'Ancho:',
	'height' => 'Alto:',
	'changepass' => 'Cambiar la contraseña',
	'oldpass' => 'Contraseña anterior:',
	'newpass' => 'Contraseña nueva:',
	'confirmpass' => 'Confirmar contraseña nueva:',
	'savechanges' => 'Guardar cambios',
	'reloadpb' => 'Recargar caja de publicación',
	'reloadmsgs' => 'Recargar mensajes',
	'chgprofile' => 'Perfil',
	'adminbtn' => 'Admin',
	'admnotes' => 'Notas de administrador',
	'notes' => 'Notas',
	'clone' => 'Clone',
	'randh' => 'Reglas y ayuda',
	'exit' => 'Salir de la sala',
	'bye' => '¡Chau %s, visitanos pronto!',
	'colourtable' => 'Colourtable',
	'backtoprofile' => 'Volver a tu perfil',
	'copy' => 'Copiar:',
	'choosecol' => 'Invitado, elija un color:',
	'randomcol' => 'Color al azar',
	'enter' => 'Ingresar a la sala',
	'error' => 'Error',
	'members' => 'Miembros',
	'guests' => 'Invitados',
	'approveguests' => '%d nuevos invitados para aprobar',
	'allowchecked' => 'Aceptar marcados',
	'allowall' => 'Aceptar todos',
	'denychecked' => 'Rechazar marcados',
	'denyall' => 'Rechazar todos',
	'denymessage' => 'Enviar mensaje a rechazados:',
	'butallowdeny' => 'Enviar',
	'waitempty' => 'No hay más peticiones para aprobar.',
	'wrongcaptcha' => 'Captcha incorrecto',
	'captchaexpire' => 'Captcha ya usado o expirado.',
	'noguests' => '¡Perdón! Actualmente sólo se permiten miembros.',
	'curchat' => 'Actualmente hay %d personas en la sala:',
	'cantreg' => 'No pudo registrarse %s',
	'alreadyreged' => '%s ya fue registrado.',
	'successreg' => '%s se registro exitosamente.',
	'cantchgstat' => 'No pudo cambiarse el estado de %s',
	'succdel' => '%s fue eliminado de la base de datos.',
	'succchg' => 'Se cambió el estado de %s exitosamente.',
	'wrongpass' => '¡Constraseña incorrecta!',
	'wrongglobalpass' => '¡Constraseña global incorrecta!',
	'succprofile' => 'Tu perfil se guardó satisfactoriamente.',
	'backtologin' => 'Volver a la página de identificación.',
	'backtochat' => 'Vovler a la sala.',
	'Beige' => 'Beis',
	'Black' => 'Negro',
	'Blue' => 'Azul',
	'BlueViolet' => 'Azul violáceo',
	'Brown' => 'Marrón',
	'Cyan' => 'Cian',
	'DarkBlue' => 'Azul oscuro',
	'DarkGreen' => 'Verde oscuro',
	'DarkRed' => 'Rojo oscuro',
	'DarkViolet' => 'Violeta oscuro',
	'DeepSkyBlue' => 'Azul celeste',
	'Gold' => 'Dorado',
	'Grey' => 'Gris',
	'Green' => 'Verde',
	'HotPink' => 'Rosa cálido',
	'Indigo' => 'Índigo',
	'LightBlue' => 'Azul claro',
	'LightGreen' => 'Verde claro',
	'LimeGreen' => 'Verde lima',
	'Magenta' => 'Magenta',
	'Olive' => 'Oliva',
	'Orange' => 'Naranja',
	'OrangeRed' => 'Rojo anaranjado',
	'Purple' => 'Púrpura',
	'Red' => 'Rojo',
	'RoyalBlue' => 'Azul real',
	'SeaGreen' => 'Verde marino',
	'Sienna' => 'Siena',
	'Silver' => 'Plateado',
	'Tan' => 'Bronceado',
	'Teal' => 'Cerceta',
	'Violet' => 'Violeta',
	'White' => 'Blanco',
	'Yellow' => 'Amarillo',
	'YellowGreen' => 'Verde amarillento',
	'redirectto' => 'Redirigir hacia:',
	'nonhttp' => 'Petición de enlace que no es http:',
	'httpredir' => 'Si no funciona, prueba esto:',
	'actions' => 'Acciones',
	'sesip' => 'Dirección IP',
	'css' => 'Estilo CSS',
	'memberexpire' => 'Expiración para miembros (minutos)',
	'guestexpire' => 'Expiración para invitados (minutos)',
	'kickpenalty' => 'Penalidad al expulsar (minutos)',
	'entrywait' => 'Tiempo en sala de espera (segundos)',
	'captchatime' => 'Expiración de captcha (segundos)',
	'messageexpire' => 'Expiracíon de mensajes (minutos)',
	'messagelimit' => 'Límite de mensajes (público)',
	'maxmessage' => 'Largo máximo de mensaje',
	'confirm' => '¿Estás seguro?',
	'yes' => 'Sí',
	'no' => 'No',
	'colbg' => 'Color de fondo',
	'coltxt' => 'Color de texto',
	'maxname' => 'Largo máximo para apodos',
	'minpass' => 'Largo mínimo para contraseñas',
	'defaultrefresh' => 'Tiempo de refresco de mensajes por defecto (segundos)',
	'suguests' => 'Habilitar aplicantes',
	'rulestxt' => 'Reglas (html)',
	'imgembed' => 'Imágenes incrustadas',
	'trackip' => 'Mostrar IP de la sesión',
	'captchachars' => 'Caracteres usados en el Captcha',
	'memkick' => 'Los miembros pueden expulsar, si no hay moderador presente',
	'forceredirect' => 'Forzar redirección',
	'redirect' => 'Script de redirección personalizado',
	'backuprestore' => 'Respaldar y restaurar',
	'backup' => 'Respaldar',
	'restore' => 'Restaurar',
	'settings' => 'Preferencias',
	'linkfilter' => 'Filtro de enlaces',
	'chatname' => 'Nombre de la sala',
	'destroy' => 'Destruir sala',
	'destroyed' => 'Sala destruida satisfactoriamente',
	'topic' => 'Asunto',
	'passreset' => 'Reiniciar contraseña',
	'cantresetpass' => 'Can\'t reset password',
	'succpassreset' => 'Successfully reset password',
	'entermsg' => '%s entró en la sala.',
	'exitmsg' => '%s se fue de la sala.',
	'memregmsg' => '%s ahora es un miembro registrado.',
	'suregmsg' => '%s ahora es un aplicante registrado.',
	'kickmsg' => '%s fue expulsado.',
	'multikickmsg' => '%s fueron expulsados.',
	'allkickmsg' => 'Todas las personas fueron expulsadas.',
	'cleanmsg' => '%s fue limpiada.',
	'sendallmsg' => '%s - ',
	'sendmemmsg' => '[M] %s - ',
	'sendmodmsg' => '[Equipo] %s - ',
	'sendadmmsg' => '[Admin] %s - ',
	'sendprvmsg' => '[%1$s a %2$s] - ',
	'msgsendall' => 'Mensajes a todos',
	'msgsendmem' => 'Sólo mensajes a miembros',
	'msgsendmod' => 'Sólo mensajes a equipo',
	'msgsendadm' => 'Sólo mensajes a administradores',
	'msgsendprv' => 'Mensaje privado',
	'numnotes' => 'Number of notes revisions to keep',
	'revisions' => 'Revisiones:',
	'older' => 'Older',
	'newer' => 'Newer',
	'accessdenied' => 'Acceso denegado',
	'loggedinas' => 'Estás identificado como %s y no tenés acceso a esta sección.',
	'newnickname' => 'Nuevo apodo:',
	'nicknametaken' => 'Ese apodo ya fue tomado',
	'nopass' => 'Constraseña incorrecta (al menos %d caracteres), no se cambia apodo'
);
?>
